@@ -13,7 +13,6 @@ import (
 	"github.com/hashicorp/go-version"
 
 	"github.com/aws/aws-sdk-go-v2/service/eks/types"
-	"github.com/aws/aws-sdk-go/aws"
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
@@ -32,12 +31,14 @@ import (
 	"github.com/weaveworks/eksctl/pkg/eks"
 	kubewrapper "github.com/weaveworks/eksctl/pkg/kubernetes"
 	"github.com/weaveworks/eksctl/pkg/testutils"
+	"github.com/weaveworks/eksctl/pkg/utils"
 	"github.com/weaveworks/eksctl/pkg/utils/file"
 )
 
 const (
-	k8sUpdatePollInterval = "30s"
-	k8sUpdatePollTimeout  = "10m"
+	k8sUpdatePollInterval  = "30s"
+	k8sUpdatePollTimeout   = "10m"
+	addonUpdatePollTimeout = "25m"
 )
 
 var (
@@ -122,7 +123,7 @@ var _ = BeforeSuite(func() {
 				Name:         initNG,
 				InstanceType: "t3.large",
 				ScalingConfig: &api.ScalingConfig{
-					DesiredCapacity: aws.Int(1),
+					DesiredCapacity: utils.IntPtr(1),
 				},
 				Labels: map[string]string{
 					"ng-name": initNG,
@@ -135,7 +136,7 @@ var _ = BeforeSuite(func() {
 				AMIFamily:    api.NodeImageFamilyBottlerocket,
 				InstanceType: "t3.small",
 				ScalingConfig: &api.ScalingConfig{
-					DesiredCapacity: aws.Int(1),
+					DesiredCapacity: utils.IntPtr(1),
 				},
 				Labels: map[string]string{
 					"ng-name": botNG,
@@ -245,7 +246,7 @@ var _ = Describe("(Integration) Upgrading cluster", func() {
 				segments := v.Segments()
 				Expect(len(segments)).To(BeNumerically(">=", 2))
 				return fmt.Sprintf("%d.%d", segments[0], segments[1])
-			}, k8sUpdatePollTimeout, k8sUpdatePollInterval).Should(Equal(nextEKSVersion))
+			}, addonUpdatePollTimeout, k8sUpdatePollInterval).Should(Equal(nextEKSVersion))
 		})
 
 		It("should upgrade aws-node", func() {
@@ -269,7 +270,7 @@ var _ = Describe("(Integration) Upgrading cluster", func() {
 					"--verbose", "4",
 				)
 			Expect(cmd).To(RunSuccessfully())
-			Eventually(getAWSNodeVersion, k8sUpdatePollTimeout, k8sUpdatePollInterval).ShouldNot(Equal(preUpdateAWSNodeVersion))
+			Eventually(getAWSNodeVersion, addonUpdatePollTimeout, k8sUpdatePollInterval).ShouldNot(Equal(preUpdateAWSNodeVersion))
 		})
 
 		It("should upgrade coredns", func() {
