@@ -1,8 +1,9 @@
 package nodebootstrap
 
 import (
+	"fmt"
+
 	"github.com/kris-nova/logger"
-	"github.com/pkg/errors"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/nodebootstrap/assets"
@@ -29,7 +30,7 @@ func NewUbuntuBootstrapper(clusterConfig *api.ClusterConfig, np api.NodePool, cl
 func (b *Ubuntu) UserData() (string, error) {
 	body, err := linuxConfig(b.clusterConfig, ubuntuBootScript, assets.BootstrapUbuntuSh, b.clusterDNS, b.np)
 	if err != nil {
-		return "", errors.Wrap(err, "encoding user data")
+		return "", fmt.Errorf("encoding user data: %w", err)
 	}
 
 	logger.Debug("user-data = %s", body)
